
|Travis|_ |Coveralls|_ |Python27|_ |Python34|_ |PyPi|_ 

.. |Travis| image:: https://travis-ci.org/neurospin/pyconnectomist.svg?branch=master
.. _Travis: https://travis-ci.org/neurospin/pyconnectomist

.. |Coveralls| image:: https://coveralls.io/repos/neurospin/pyconnectomist/badge.svg?branch=master&service=github
.. _Coveralls: https://coveralls.io/github/neurospin/pyconnectomist

.. |Python27| image:: https://img.shields.io/badge/python-2.7-blue.svg
.. _Python27: https://badge.fury.io/py/pyconnectomist

.. |Python34| image:: https://img.shields.io/badge/python-3.4-blue.svg
.. _Python34: https://badge.fury.io/py/pyconnectomist

.. |PyPi| image:: https://badge.fury.io/py/pyconnectomist.svg
.. _PyPi: https://badge.fury.io/py/pyconnectomist


===============
pyConnectomist
===============

[pyconnectomist] A Python project that provides a wrapping over the uniform
Connectomist software interface. Visit also the
`API documentation <http://neurospin.github.io/pyconnectomist>`_.





